@@ -43,10 +43,10 @@
 
 // Original author: Justin Blair
 
-#include <stdlib.h>
 #include <math.h>
+#include <stdlib.h>
 
-#include "remove_ring.h"
+#include "libtomo/remove_ring.h"
 
 #define INT_MODE_WRAP 0
 #define INT_MODE_REFLECT 1
