@@ -82,7 +82,7 @@ __all__ = ['align_seq',
            'remove_slits_aps_1id',
            'distortion_correction_proj',
            'distortion_correction_sino',
-           'load_distortion_coefs',           
+           'load_distortion_coefs',
            ]
 
 
@@ -190,7 +190,7 @@ def align_seq(
 
             # Register current projection in sub-pixel precision
             shift, error, diffphase = phase_cross_correlation(
-                    _prj[m], _sim[m], upsample_factor)
+                    _prj[m], _sim[m], upsample_factor=upsample_factor)
             err[m] = np.sqrt(shift[0]*shift[0] + shift[1]*shift[1])
             sx[m] += shift[0]
             sy[m] += shift[1]
@@ -214,7 +214,7 @@ def align_seq(
 
 
 def align_joint(
-        prj, ang, fdir='.', iters=10, pad=(0, 0),
+        prj, ang, fdir='./', iters=10, pad=(0, 0),
         blur=True, center=None, algorithm='sirt',
         upsample_factor=10, rin=0.5, rout=0.8,
         save=False, debug=True):
@@ -300,6 +300,9 @@ def align_joint(
     if algorithm != 'gridrec':
         extra_kwargs['num_iter'] = 1
 
+    # Make a copy of the projections
+    prj_copy = prj.copy()
+
     # Register each image frame-by-frame.
     for n in range(iters):
 
@@ -307,7 +310,7 @@ def align_joint(
             _rec = rec
 
         # Reconstruct image.
-        rec = recon(prj, ang, center=center, algorithm=algorithm,
+        rec = recon(prj_copy, ang, center=center, algorithm=algorithm,
                     init_recon=_rec, **extra_kwargs)
 
         # Re-project data and obtain simulated data.
@@ -315,10 +318,10 @@ def align_joint(
 
         # Blur edges.
         if blur:
-            _prj = blur_edges(prj, rin, rout)
+            _prj = blur_edges(prj_copy, rin, rout)
             _sim = blur_edges(sim, rin, rout)
         else:
-            _prj = prj
+            _prj = prj_copy
             _sim = sim
 
         # Initialize error matrix per iteration.
@@ -329,23 +332,27 @@ def align_joint(
 
             # Register current projection in sub-pixel precision
             shift, error, diffphase = phase_cross_correlation(
-                    _prj[m], _sim[m], upsample_factor)
+                    _prj[m], _sim[m], normalization=None,
+                    upsample_factor=upsample_factor)
             err[m] = np.sqrt(shift[0]*shift[0] + shift[1]*shift[1])
             sx[m] += shift[0]
             sy[m] += shift[1]
 
             # Register current image with the simulated one
-            tform = tf.SimilarityTransform(translation=(shift[1], shift[0]))
-            prj[m] = tf.warp(prj[m], tform, order=5)
+            tform = tf.SimilarityTransform(translation=(sy[m], sx[m]))
+            prj_copy[m] = tf.warp(prj[m].copy(), tform, order=5)
 
         if debug:
-            print('iter=' + str(n) + ', err=' + str(np.linalg.norm(err)))
+            print('iter=' + str(n) + 
+                  ', err=' + str(np.linalg.norm(err) / prj.shape[0]))
             conv[n] = np.linalg.norm(err)
 
         if save:
-            write_tiff(prj, 'tmp/iters/prj', n)
-            write_tiff(sim, 'tmp/iters/sim', n)
-            write_tiff(rec, 'tmp/iters/rec', n)
+            write_tiff(_prj, fdir + 'tmp/iters/prj', n)
+            write_tiff(sim, fdir + 'tmp/iters/sim', n)
+            write_tiff(rec, fdir + 'tmp/iters/rec', n)
+            write_tiff(sx, fdir + 'tmp/iters/sx', n)
+            write_tiff(sy, fdir + 'tmp/iters/sy', n)
 
     # Re-normalize data
     prj *= scl
@@ -915,6 +922,8 @@ def distortion_correction_proj(tomo, xcenter, ycenter, list_fact,
     Apply distortion correction to projections using the polynomial model.
     Coefficients are calculated using Vounwarp package :cite:`Vo:15`.
 
+    .. versionadded:: 1.7
+
     Parameters
     ----------
     tomo : ndarray
@@ -922,7 +931,7 @@ def distortion_correction_proj(tomo, xcenter, ycenter, list_fact,
     xcenter : float
         Center of distortion in x-direction. From the left of the image.
     ycenter : float
-        Center of distortion in y-direction. From the top of the image. 
+        Center of distortion in y-direction. From the top of the image.
     list_fact : list of floats
         Polynomial coefficients of the backward model.
     ncore : int, optional
@@ -948,17 +957,17 @@ def distortion_correction_proj(tomo, xcenter, ycenter, list_fact,
 def _unwarp_image_backward(mat, xcenter, ycenter, list_fact):
     """
     Unwarp an image using the polynomial model.
-    
+
     Parameters
     ----------
     mat : 2D array.
-    xcenter : float 
+    xcenter : float
             Center of distortion in x-direction. From the left of the image.
     ycenter : float
             Center of distortion in y-direction. From the top of the image.
-    list_fact : list of floats 
+    list_fact : list of floats
             Polynomial coefficients of the backward model.
-    
+
     Returns
     -------
     2D array
@@ -982,7 +991,7 @@ def _unwarp_image_backward(mat, xcenter, ycenter, list_fact):
 def _distortion_correction_proj(tomo, xcenter, ycenter, list_fact):
     for m in np.arange(tomo.shape[0]):
         proj = tomo[m, :, :]
-        proj = _unwarp_image_backward(proj, xcenter, ycenter, list_fact)        
+        proj = _unwarp_image_backward(proj, xcenter, ycenter, list_fact)
         tomo[m, :, :] = proj
 
 
@@ -992,6 +1001,8 @@ def distortion_correction_sino(tomo, ind, xcenter, ycenter, list_fact):
     the polynomial model. Coefficients are calculated using Vounwarp
     package :cite:`Vo:15`.
 
+    .. versionadded:: 1.7
+
     Parameters
     ----------
     tomo : ndarray
@@ -1001,7 +1012,7 @@ def distortion_correction_sino(tomo, ind, xcenter, ycenter, list_fact):
     xcenter : float
         Center of distortion in x-direction. From the left of the image.
     ycenter : float
-        Center of distortion in y-direction. From the top of the image.         
+        Center of distortion in y-direction. From the top of the image.
     list_fact : list of floats
         Polynomial coefficients of the backward model.
 
@@ -1021,7 +1032,7 @@ def distortion_correction_sino(tomo, ind, xcenter, ycenter, list_fact):
     yd_list = np.clip(ycenter + flist * yu, 0, height - 1)
     yd_min = np.int16(np.floor(np.amin(yd_list)))
     yd_max = np.int16(np.ceil(np.amax(yd_list))) + 1
-    yd_list = yd_list - yd_min 
+    yd_list = yd_list - yd_min
     sino = np.zeros((depth, width), dtype=np.float32)
     indices = yd_list, xd_list
     for i in np.arange(depth):
